@@ -40,3 +40,23 @@ class ReplaceNonAsciiBytes(StringFilter[bytes]):
 def apply_filters(string: AnyStr, *args: StringFilter|Type[StringFilter]) -> AnyStr:
     filters = map(lambda t: t() if isinstance(t, type) else t, args)
     return reduce(lambda s, f: f.apply(s), filters, string)
+
+
+def ljust_fmtd(s: str, width: int, fillchar: str = ' ') -> str:
+    sanitized = ReplaceSGR().apply(s)
+    return s + fillchar * max(0, width - len(sanitized))
+
+
+def rjust_fmtd(s: str, width: int, fillchar: str = ' ') -> str:
+    sanitized = ReplaceSGR().apply(s)
+    return fillchar * max(0, width - len(sanitized)) + s
+
+
+def center_fmtd(s: str, width: int, fillchar: str = ' ') -> str:
+    sanitized = ReplaceSGR().apply(s)
+    fill_len = max(0, width - len(sanitized))
+    if fill_len == 0:
+        return s
+    right_fill_len = fill_len // 2
+    left_fill_len = fill_len - right_fill_len
+    return (fillchar * left_fill_len) + s + (fillchar * right_fill_len)
